@@ -9,7 +9,7 @@ int bufsize;
 {
   int r;
   for (;;) {
-    if (!stralloc_readyplus(sa,bufsize)) return -1;
+    if (!stralloc_readyplus(sa,bufsize)) { close(fd); return -1; }
     r = read(fd,sa->s + sa->len,bufsize);
     if (r <= 0) { close(fd); return r; }
     sa->len += r;
